@@ -30,13 +30,13 @@ if 'PYTHONWARNINGS' not in os.environ:
 warnings.filterwarnings('ignore', "'U' mode is deprecated",
                         DeprecationWarning, module='docutils.io')
 
-__version__  = '1.5'
-__released__ = '1.5'  # used when Sphinx builds its own docs
+__version__  = '1.5.1'
+__released__ = '1.5.1'  # used when Sphinx builds its own docs
 
 # version info for better programmatic use
 # possible values for 3rd element: 'alpha', 'beta', 'rc', 'final'
 # 'final' has 0 as the last element
-version_info = (1, 5, 0, 'final', 0)
+version_info = (1, 5, 1, 'final', 0)
 
 package_dir = path.abspath(path.dirname(__file__))
 
