@@ -576,19 +576,16 @@ class LaTeXTranslator(nodes.NodeVisitor):
             '\\label{%s}' % self.idescape(id)
 
     def hyperlink(self, id):
-        return '{\\hyperref[%s]{' % self.hyperrefescape(id)
+        return '{\\hyperref[%s]{' % self.idescape(id)
 
     def hyperpageref(self, id):
         return '\\autopageref*{%s}' % self.idescape(id)
 
     def idescape(self, id):
-        return text_type(id).translate(tex_replace_map).\
+        return '\\detokenize{%s}' % text_type(id).translate(tex_replace_map).\
             encode('ascii', 'backslashreplace').decode('ascii').\
             replace('\\', '_')
 
-    def hyperrefescape(self, ref):
-        return self.idescape(ref).replace('-', '\\string-')
-
     def babel_renewcommand(self, command, definition):
         if self.elements['multilingual']:
             prefix = '\\addto\\captions%s{' % self.babel.get_language()
